@@ -21,23 +21,22 @@
  */
 
 #include "config.h"
+#include "empathy-avatar-chooser.h"
 
 #include <glib/gi18n-lib.h>
 
-#include <libempathy/empathy-camera-monitor.h>
-#include <libempathy/empathy-gsettings.h>
-#include <libempathy/empathy-utils.h>
-
-#include "empathy-avatar-chooser.h"
-#include "empathy-images.h"
-#include "empathy-ui-utils.h"
-
 #ifdef HAVE_CHEESE
 #include <cheese-avatar-chooser.h>
 #endif /* HAVE_CHEESE */
 
+#include "empathy-camera-monitor.h"
+#include "empathy-gsettings.h"
+#include "empathy-images.h"
+#include "empathy-ui-utils.h"
+#include "empathy-utils.h"
+
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 /**
  * SECTION:empathy-avatar-chooser
@@ -854,7 +853,7 @@ avatar_chooser_update_preview_cb (GtkFileChooser *file_chooser,
       else
         {
           gtk_image_set_from_stock (GTK_IMAGE (image),
-                  "gtk-dialog-question",
+                  "dialog-question",
                   GTK_ICON_SIZE_DIALOG);
         }
 
