@@ -22,10 +22,10 @@
  */
 
 #include "config.h"
-
-#include <libempathy/empathy-utils.h>
 #include "empathy-cell-renderer-text.h"
 
+#include "empathy-utils.h"
+
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyCellRendererText)
 typedef struct {
 	gchar    *name;
