@@ -20,20 +20,19 @@
  */
 
 #include "config.h"
+#include "empathy-contact-widget.h"
 
 #include <glib/gi18n-lib.h>
 
-#include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-client-factory.h>
-
-#include "empathy-contact-widget.h"
 #include "empathy-avatar-image.h"
+#include "empathy-client-factory.h"
 #include "empathy-groups-widget.h"
-#include "empathy-ui-utils.h"
 #include "empathy-string-parser.h"
+#include "empathy-ui-utils.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 /**
  * SECTION:empathy-contact-widget
