@@ -25,25 +25,25 @@
  */
 
 #include "config.h"
+#include "empathy-individual-view.h"
 
 #include <glib/gi18n-lib.h>
 
-#include <libempathy/empathy-connection-aggregator.h>
-#include <libempathy/empathy-individual-manager.h>
-#include <libempathy/empathy-contact-groups.h>
-#include <libempathy/empathy-request-util.h>
-#include <libempathy/empathy-utils.h>
-
-#include "empathy-individual-edit-dialog.h"
-#include "empathy-images.h"
+#include "empathy-cell-renderer-activatable.h"
 #include "empathy-cell-renderer-expander.h"
 #include "empathy-cell-renderer-text.h"
-#include "empathy-cell-renderer-activatable.h"
-#include "empathy-ui-utils.h"
+#include "empathy-connection-aggregator.h"
+#include "empathy-contact-groups.h"
 #include "empathy-gtk-enum-types.h"
+#include "empathy-images.h"
+#include "empathy-individual-edit-dialog.h"
+#include "empathy-individual-manager.h"
+#include "empathy-request-util.h"
+#include "empathy-ui-utils.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 /* Active users are those which have recently changed state
  * (e.g. online, offline or from normal to a busy state).
