@@ -25,15 +25,16 @@
  */
 
 #include "config.h"
+#include "empathy-presence-chooser.h"
 
 #include <glib/gi18n-lib.h>
 
-#include <libempathy/empathy-presence-manager.h>
-#include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-status-presets.h>
+#include "empathy-presence-manager.h"
+#include "empathy-status-presets.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 #include "empathy-ui-utils.h"
 #include "empathy-presence-chooser.h"
