@@ -21,17 +21,16 @@
  */
 
 #include "config.h"
+#include "empathy-protocol-chooser.h"
 
 #include <glib/gi18n-lib.h>
 
-#include <libempathy/empathy-utils.h>
-#include <libempathy/empathy-connection-managers.h>
-
-#include "empathy-protocol-chooser.h"
+#include "empathy-connection-managers.h"
 #include "empathy-ui-utils.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 /**
  * SECTION:empathy-protocol-chooser
