@@ -1,14 +1,12 @@
 #include "config.h"
-
 #include "empathy-roster-view.h"
 
 #include <glib/gi18n-lib.h>
 
-#include <libempathy/empathy-contact-groups.h>
-
-#include <libempathy-gtk/empathy-roster-contact.h>
-#include <libempathy-gtk/empathy-roster-group.h>
-#include <libempathy-gtk/empathy-ui-utils.h>
+#include "empathy-contact-groups.h"
+#include "empathy-roster-contact.h"
+#include "empathy-roster-group.h"
+#include "empathy-ui-utils.h"
 
 G_DEFINE_TYPE (EmpathyRosterView, empathy_roster_view, EGG_TYPE_LIST_BOX)
 
