@@ -19,15 +19,15 @@
  */
 
 #include "config.h"
-
 #include "empathy-account-settings.h"
+
 #include "empathy-connection-managers.h"
 #include "empathy-keyring.h"
-#include "empathy-utils.h"
 #include "empathy-presence-manager.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyAccountSettings)
 
