@@ -17,11 +17,9 @@
  */
 
 #include "config.h"
-
-#include <glib/gi18n-lib.h>
-
 #include "empathy-keyring.h"
 
+#include <glib/gi18n-lib.h>
 #include <libsecret/secret.h>
 
 #ifdef HAVE_UOA
@@ -51,12 +49,6 @@ static const SecretSchema room_keyring_schema =
       { "room-id", SECRET_SCHEMA_ATTRIBUTE_STRING },
       { NULL } } };
 
-gboolean
-empathy_keyring_is_available (void)
-{
-  return TRUE;
-}
-
 /* get */
 
 static void
@@ -664,8 +656,7 @@ items_delete_cb (GObject *source,
   GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT (user_data);
   GError *error = NULL;
 
-  secret_password_clear_finish (result, &error);
-  if (error != NULL)
+  if (!secret_password_clear_finish (result, &error))
     {
       g_simple_async_result_set_error (simple, TP_ERROR,
               TP_ERROR_DOES_NOT_EXIST, "%s", error->message);
