@@ -27,7 +27,6 @@
 
 #include <glib.h>
 #include <glib-object.h>
-
 #include <gnutls/x509.h>
 #include <libxml/tree.h>
 #include <folks/folks.h>
@@ -44,8 +43,8 @@ G_BEGIN_DECLS
 void empathy_init (void);
 
 /* XML */
-gboolean empathy_xml_validate (xmlDoc *doc,
-    const gchar *dtd_filename);
+gboolean empathy_xml_validate_from_resource (xmlDoc *doc,
+    const gchar *dtd_resourcename);
 xmlNodePtr empathy_xml_node_get_child (xmlNodePtr node,
     const gchar *child_name);
 xmlChar * empathy_xml_node_get_child_content (xmlNodePtr node,
