@@ -23,19 +23,17 @@
 #include "config.h"
 
 #include <glib/gi18n.h>
-
 #include <libnotify/notify.h>
 
-#include <libempathy/empathy-presence-manager.h>
-
-#include <libempathy-gtk/empathy-theme-manager.h>
-#include <libempathy-gtk/empathy-ui-utils.h>
-
 #include "empathy-chat-manager.h"
 #include "empathy-chat-resources.h"
+#include "empathy-presence-manager.h"
+#include "empathy-theme-manager.h"
+#include "empathy-ui-utils.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_CHAT
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 /* Exit after $TIMEOUT seconds if not displaying any call window */
 #define TIMEOUT 60
@@ -68,6 +66,7 @@ activate_cb (GApplication *application)
     return;
 
   activated = TRUE;
+  empathy_gtk_init ();
 
   if (!use_timer)
     {
@@ -100,7 +99,7 @@ main (int argc,
   gint retval;
 
   optcontext = g_option_context_new (N_("- Empathy Chat Client"));
-  g_option_context_add_group (optcontext, gtk_get_option_group (TRUE));
+  g_option_context_add_group (optcontext, gtk_get_option_group (FALSE));
   g_option_context_add_main_entries (optcontext, options, GETTEXT_PACKAGE);
   g_option_context_set_translation_domain (optcontext, GETTEXT_PACKAGE);
 
@@ -115,7 +114,7 @@ main (int argc,
 
   g_option_context_free (optcontext);
 
-  empathy_gtk_init ();
+  empathy_init ();
 
   /* Make empathy and empathy-chat appear as the same app in gnome-shell */
   gdk_set_program_class ("Empathy");
