@@ -28,17 +28,16 @@
 /* The original file transfer manager code was copied from Epiphany */
 
 #include "config.h"
+#include "empathy-ft-manager.h"
 
 #include <glib/gi18n.h>
 
+#include "empathy-geometry.h"
+#include "empathy-ui-utils.h"
+#include "empathy-utils.h"
+
 #define DEBUG_FLAG EMPATHY_DEBUG_FT
-#include <libempathy/empathy-debug.h>
-#include <libempathy/empathy-utils.h>
-
-#include <libempathy-gtk/empathy-ui-utils.h>
-#include <libempathy-gtk/empathy-geometry.h>
-
-#include "empathy-ft-manager.h"
+#include "empathy-debug.h"
 
 enum
 {
