@@ -24,21 +24,19 @@
  */
 
 #include "config.h"
+#include "empathy-preferences.h"
 
 #include <glib/gi18n.h>
 
-#include <libempathy/empathy-client-factory.h>
-#include <libempathy/empathy-gsettings.h>
-#include <libempathy/empathy-utils.h>
-
-#include <libempathy-gtk/empathy-ui-utils.h>
-#include <libempathy-gtk/empathy-theme-manager.h>
-#include <libempathy-gtk/empathy-spell.h>
-
-#include "empathy-preferences.h"
+#include "empathy-client-factory.h"
+#include "empathy-gsettings.h"
+#include "empathy-spell.h"
+#include "empathy-theme-manager.h"
+#include "empathy-ui-utils.h"
+#include "empathy-utils.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 G_DEFINE_TYPE (EmpathyPreferences, empathy_preferences, GTK_TYPE_DIALOG);
 
@@ -1026,7 +1024,7 @@ empathy_preferences_init (EmpathyPreferences *preferences)
 	gtk_window_set_role (GTK_WINDOW (preferences), "preferences");
 	gtk_window_set_position (GTK_WINDOW (preferences),
 				 GTK_WIN_POS_CENTER_ON_PARENT);
-	gtk_window_set_icon_name (GTK_WINDOW (preferences), "gtk-preferences");
+	gtk_window_set_icon_name (GTK_WINDOW (preferences), "preferences-desktop");
 
 	filename = empathy_file_lookup ("empathy-preferences.ui", "src");
 	gui = empathy_builder_get_file (filename,
